@@ -1,6 +1,7 @@
 #' Missing distribution
 #'
-#' \lifecycle{experimental}
+#' @description
+#' `r lifecycle::badge('maturing')`
 #'
 #' A placeholder distribution for handling missing values in a vector of
 #' distributions.
@@ -68,7 +69,7 @@ generate.dist_na <- function(x, times, ...){
 mean.dist_na <- function(x, ...) NA_real_
 
 #' @export
-variance.dist_na <- function(x, ...) NA_real_
+covariance.dist_na <- function(x, ...) NA_real_
 
 #' @export
 skewness.dist_na <- function(x, ...) NA_real_
