@@ -1,6 +1,7 @@
 #' Percentile distribution
 #'
-#' \lifecycle{maturing}
+#' @description
+#' `r lifecycle::badge('stable')`
 #'
 #' @param x A list of values
 #' @param percentile A list of percentiles
@@ -18,11 +19,6 @@ dist_percentile <- function(x, percentile){
   new_dist(x = x, percentile = percentile, class = "dist_percentile")
 }
 
-#' @export
-print.dist_percentile <- function(x, ...){
-  cat(format(x, ...))
-}
-
 #' @export
 format.dist_percentile <- function(x, ...){
   sprintf(
@@ -38,7 +34,9 @@ format.dist_percentile <- function(x, ...){
 
 #' @export
 quantile.dist_percentile <- function(x, p, ...){
-  stats::approx(x = x[["percentile"]]/100, y = x[["x"]], xout = p)$y
+  out <- x[["x"]][match(p, x[["percentile"]])]
+  out[is.na(out)] <- stats::approx(x = x[["percentile"]]/100, y = x[["x"]], xout = p[is.na(out)])$y
+  out
 }
 
 #' @export
